==> discord-0.10.4.tar.gz: lib/discord.dart <==
export 'src/client.dart';
export 'src/http.dart';
export 'src/ws.dart';
export 'src/ss.dart';
export 'src/util.dart';

export 'src/events/ChannelCreateEvent.dart';
export 'src/events/ChannelDeleteEvent.dart';
export 'src/events/ChannelUpdateEvent.dart';
export 'src/events/GuildBanAddEvent.dart';
export 'src/events/GuildBanRemoveEvent.dart';
export 'src/events/GuildCreateEvent.dart';
export 'src/events/GuildDeleteEvent.dart';
export 'src/events/GuildMemberAddEvent.dart';
export 'src/events/GuildMemberRemoveEvent.dart';
export 'src/events/GuildMemberUpdateEvent.dart';
export 'src/events/GuildUpdateEvent.dart';
export 'src/events/MessageDeleteEvent.dart';
export 'src/events/MessageEvent.dart';
export 'src/events/MessageUpdateEvent.dart';
export 'src/events/ReadyEvent.dart';
export 'src/events/TypingEvent.dart';
export 'src/events/WebSocketErrorEvent.dart';

export 'src/objects/Attachment.dart';
export 'src/objects/ClientOAuth2Application.dart';
export 'src/objects/ClientOptions.dart';
export 'src/objects/ClientUser.dart';
export 'src/objects/Collection.dart';
export 'src/objects/Embed.dart';
export 'src/objects/EmbedProvider.dart';
export 'src/objects/EmbedThumbnail.dart';
export 'src/objects/Guild.dart';
export 'src/objects/GuildChannel.dart';
export 'src/objects/Invite.dart';
export 'src/objects/InviteChannel.dart';
export 'src/objects/InviteGuild.dart';
export 'src/objects/Member.dart';
export 'src/objects/MessageOptions.dart';
export 'src/objects/Message.dart';
export 'src/objects/OAuth2Application.dart';
export 'src/objects/OAuth2Guild.dart';
export 'src/objects/OAuth2Info.dart';
export 'src/objects/PrivateChannel.dart';
export 'src/objects/User.dart';

==> discord-0.11.1.tar.gz: lib/discord.dart <==
export 'src/client.dart';
export 'src/ss.dart';

export 'src/events/ChannelCreateEvent.dart';
export 'src/events/ChannelDeleteEvent.dart';
export 'src/events/ChannelUpdateEvent.dart';
export 'src/events/GuildBanAddEvent.dart';
export 'src/events/GuildBanRemoveEvent.dart';
export 'src/events/GuildCreateEvent.dart';
export 'src/events/GuildDeleteEvent.dart';
export 'src/events/GuildMemberAddEvent.dart';
export 'src/events/GuildMemberRemoveEvent.dart';
export 'src/events/GuildMemberUpdateEvent.dart';
export 'src/events/GuildUnavailableEvent.dart';
export 'src/events/GuildUpdateEvent.dart';
export 'src/events/MessageDeleteEvent.dart';
export 'src/events/MessageEvent.dart';
export 'src/events/MessageUpdateEvent.dart';
export 'src/events/ReadyEvent.dart';
export 'src/events/TypingEvent.dart';

export 'src/objects/Attachment.dart';
export 'src/objects/ClientOAuth2Application.dart';
export 'src/objects/ClientOptions.dart';
export 'src/objects/ClientUser.dart';
export 'src/objects/Collection.dart';
export 'src/objects/Embed.dart';
export 'src/objects/EmbedProvider.dart';
export 'src/objects/EmbedThumbnail.dart';
export 'src/objects/Guild.dart';
export 'src/objects/GuildChannel.dart';
export 'src/objects/Invite.dart';
export 'src/objects/InviteChannel.dart';
export 'src/objects/InviteGuild.dart';
export 'src/objects/Member.dart';
export 'src/objects/MessageOptions.dart';
export 'src/objects/Message.dart';
export 'src/objects/OAuth2Application.dart';
export 'src/objects/OAuth2Guild.dart';
export 'src/objects/OAuth2Info.dart';
export 'src/objects/PrivateChannel.dart';
export 'src/objects/User.dart';
